@@ -33,7 +33,7 @@ void BingProvider::pageRequestFinished(KJob *_job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>(_job);
     if (job->error()) {
-        emit error(this);
+        Q_EMIT error(this);
         return;
     }
 
@@ -60,7 +60,7 @@ void BingProvider::pageRequestFinished(KJob *_job)
         return;
     } while (0);
 
-    emit error(this);
+    Q_EMIT error(this);
     return;
 }
 
@@ -68,12 +68,12 @@ void BingProvider::imageRequestFinished(KJob *_job)
 {
     KIO::StoredTransferJob *job = static_cast<KIO::StoredTransferJob *>(_job);
     if (job->error()) {
-        emit error(this);
+        Q_EMIT error(this);
         return;
     }
     QByteArray data = job->data();
     mImage = QImage::fromData(data);
-    emit finished(this);
+    Q_EMIT finished(this);
 }
 
 K_PLUGIN_CLASS_WITH_JSON(BingProvider, "bingprovider.json")
